@@ -218,14 +218,28 @@ _nlu_requests = {
     },
 
 
+    # transition to videogames if we haven't talked about it already
+    '[{'
+    '[do you, know], [have you, heard], [tell me about],'
+    '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
+    '}, {[!video #LEM(game)],xbox,playstation,p s,ps,nintendo,switch,minecraft,fortnite,overwatch}]'
+    '#CNC(videogames) #IF($vgamev!=True) #GCLR':{
+        'state': 'videogames:request',
+        'score': 9.1
+    },
+
     # transition to videogames
     '[{'
     '[do you, know], [have you, heard], [tell me about],'
     '[!#NOT(not)[{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about?]'
     '}, {[!video #LEM(game)],xbox,playstation,p s,ps,nintendo,switch,minecraft,fortnite,overwatch}]'
-    '#CNC(videogames) #GCLR':{
-        'state': 'videogames:request',
-        'score': 9.1
+    '#CNC(videogames) #IF($vgamev=True) #GCLR': {
+        'state': 'return_to_vgames',
+        'score': 9.1,
+
+        '`I am still learning more about video games at the moment. There really are quite a number to look into! '
+        'Anyway, `':
+            'SYSTEM:root'
     },
 
     # transition to corona
@@ -268,7 +282,7 @@ _nlu_requests = {
     '<#NOT(pet,pets,animal,animals,dog,dogs,cat,cats),#NOT(race,races,racing)>'
     '{'
     '[tell me about, $topic_requested=/.+/], '
-    '[tell me, {news,politics,technology,business,events,movies,shows,music,songs,concerts}],'
+    '[{to hear,tell me}, {news,politics,technology,business,events,movies,shows,music,songs,concerts}],'
     '[! #NOT(not) [{let us, we, you, can you, can we, could you, could we}] {talk, converse, conversation, discuss, discussion, chat} about $topic_requested=/.+/]'
     '}'
     '#GCLR':{
@@ -282,7 +296,9 @@ _nlu_requests = {
         '[{music,musics,tunes,song,songs,melody,melodies,album,albums,concert,concerts}]':
             'SYSTEM:music_intro',
 
-        '[{news,politics,technology,business,events}]':
+        '[{news,politics,political,technology,business,events,world,nation,country,primaries,walk outs,walk out,'
+        '#LEM(protest,rally,vote,election,strike,demonstration,march,riot,government),'
+        'spacex,space x,space shuttle,space launch,trump,pence,obama,clinton,biden,sanders}]':
             'SYSTEM:external_news_intro',
 
         '[{sport,sports,basketball,football,hockey,tennis,baseball,soccer,superbowl,kobe bryant}]':
@@ -294,25 +310,25 @@ _nlu_requests = {
             '`I don\'t think I know anything about that, but `':{
                 'hop': 'True',
 
-                '#SBS($topic_requested, cat dog pets animals animal) `We can talk about pets instead! `':
+                '#SBS($topic_requested, cat dog pets animals animal) #IF($petv!=True) `We can talk about pets instead! `':
                     'SYSTEM:pet_intro',
 
-                '#SBS($topic_requested, sports basketball football soccer) `We can talk about other sports! `':
+                '#SBS($topic_requested, sports basketball football soccer) #IF($sportsv!=True) `We can talk about other sports! `':
                     'SYSTEM:sports_intro',
 
-                '#SBS($topic_requested, virtual augmented reality videogame) ` it kind of sounds like it\'s related to virtual reality. `':
+                '#SBS($topic_requested, virtual augmented reality videogame) #IF($virtual_realityv!=True) ` it kind of sounds like it\'s related to virtual reality. `':
                     'SYSTEM:virtual_reality_intro',
 
-                '#SBS($topic_requested, video game skyrim rimworld halo mario minecraft fortnite overwatch) ` it reminds me of video games. `':
+                '#SBS($topic_requested, video game skyrim rimworld halo mario minecraft fortnite overwatch) #IF($vgamev!=True) ` it reminds me of video games. `':
                     'videogames:request',
 
-                '#SBS($topic_requested, travel vacation city state country location place) ` maybe you are interested in talking about travel plans. `':
+                '#SBS($topic_requested, travel vacation city state country location place) #IF($travelv!=True) ` maybe you are interested in talking about travel plans. `':
                     'SYSTEM:travel_intro',
 
-                '#SBS($topic_requested, movie film show television watch cinema) ` we can talk about some movies! `':
+                '#SBS($topic_requested, movie film show television watch cinema) #IF($moviesv!=True)` we can talk about some movies! `':
                     'SYSTEM:movies_intro',
 
-                '#SBS($topic_requested, music song album sing dance) ` we can talk about your music interests! `':
+                '#SBS($topic_requested, music song album sing dance) #IF($musicv!=True) ` we can talk about your music interests! `':
                     'SYSTEM:music_intro',
 
                 '#DEFAULT `it sounds interesting so I will put it on my list of things to learn more about! '
@@ -320,6 +336,51 @@ _nlu_requests = {
                     'SYSTEM:root'
             }
         }
-    }
+    },
 
+    '{$off_phrase=[!#ONT(ontturn), #ONT(ontoff)],'
+    '$off_phrase=[!#ONT(ontturn), to, #ONT(ontoff)],'
+    '$off_phrase=[!{alexa,echo,computer}?, #ONT(ontoff)+],'
+    '[$off_phrase=[!{alexa,echo,computer}, #ONT(ontturn), {#ONT(ontoffpaired),#ONT(ontoff)}]],'
+    '[$off_phrase=[!{alexa,echo,computer}, #ONT(ontturn), to, {#ONT(ontoffpaired),#ONT(ontoff)}]],'
+    '[$off_phrase={goodnight, good night,shut up}],'
+    '$off_phrase=[!{alexa,echo,computer}?, {cancel,abandon}],'
+    '[$off_phrase=[!{done,finished,over,[{dont,not} {want,wanna,feel like}]} to? #LEM(talk,chat) {now,to you,with you}]],'
+    '[$off_phrase=[!{wanna,want to,like to} {finish,end,stop} {this conversation}]],'
+    '[$off_phrase=[!{wanna,want to} {be} {done,finished}]]}':{
+        'state': 'stop_request',
+        'score': 11,
+
+        '`I heard you say ` $off_phrase `. If you would like to exit the conversation, say Alexa stop.`':{
+            'state': 'stop_instr',
+
+            '{$off_phrase=[!#ONT(ontturn), #ONT(ontoff)],'
+            '$off_phrase=[!#ONT(ontturn), to, #ONT(ontoff)],'
+            '$off_phrase=[!{alexa,echo,computer}?, #ONT(ontoff)+],'
+            '[$off_phrase=[!{alexa,echo,computer}, #ONT(ontturn), {#ONT(ontoffpaired),#ONT(ontoff)}]],'
+            '[$off_phrase=[!{alexa,echo,computer}, #ONT(ontturn), to, {#ONT(ontoffpaired),#ONT(ontoff)}]],'
+            '[$off_phrase={goodnight, good night,shut up}],'
+            '$off_phrase=[!{alexa,echo,computer}?, {cancel,abandon,"go away"}],'
+            '[$off_phrase=[!{done,finished,over,[{dont,not} {want,wanna,feel like}]} to? {[!keep #LEM(talk,chat)], [!#LEM(talk,chat) {anymore,now,to you,with you}]}]],'
+            '[$off_phrase=[!{wanna,want to,like to} {finish,end,stop} {this conversation}]],'
+            '[$off_phrase=[!{wanna,want to} {be} {done,finished}]]}':{
+                'state': 'stop_request_2',
+                'score': 12,
+
+                '`I am sorry, but I have a hard time understanding phrases like ` $off_phrase ` because it seems like '
+                'you want to stop talking. If you actually do want to stop, you must say Alexa stop. Otherwise, I am '
+                'happy to continue our conversation.`':{
+                    'state': 'final_stop_instr',
+
+                    'error': {
+                        'state': 'stop_redirect',
+
+                        '`Ok, well, let us get back to our conversation then. ` #GRET': 'SYSTEM:root'
+                    }
+                }
+            },
+
+            'error': 'stop_redirect'
+        }
+    }
 }
\ No newline at end of file
