@@ -1,11 +1,11 @@
 from _globals import PATHDIR
 from emora_stdm import DialogueFlow
 from emora_stdm.state_transition_dialogue_manager.natex_common import CommonNatexMacro
+from emora._flows._central_knowledge import central_knowledge
 
 
-baby = DialogueFlow('_local_start')
+baby = DialogueFlow('_local_start', kb=central_knowledge)
 
-baby.knowledge_base().load_json_file(PATHDIR.replace('__***__','_common.json'))
 baby.add_system_transition('_local_start', 'start', '')
 
 system = {
@@ -29,7 +29,7 @@ system = {
         },
 
         '{#AGREE,[i do #NOT(not)]}'
-        '#SET($has_kids=True)':{
+        '#SET($has_children=True)':{
             'state': 'ask_user_kids_age',
             'score': 0.9,
 
@@ -60,7 +60,7 @@ system = {
         },
 
         '[{#DISAGREE,i do not}]'
-        '#SET($has_kids=False)':{
+        '#SET($has_children=False)':{
 
             '`Me neither. Thinking about having kids myself just sounds weird, '
             'I am still learning so much myself that I don\'t think I\'m ready to '
@@ -339,6 +339,30 @@ traditions = {
     }
 }
 
+returning = {
+    'state': 'returning',
+    'enter': '#GATE #KNOWN($has_children=True)',
+
+    '`I think last time we talked, you told me about your kids, right? How have they been?`': {
+
+        '[#ONT(_positive adj)]': {
+
+            '`That\'s good. I bet they\'re happy to be off school for so long.`': {
+
+                '#UNX': 'exit'
+            }
+        },
+
+        'error': {
+
+            '`I see. I bet they\'re happy to be off school for so long, huh?.`': {
+
+                '#UNX': 'exit'
+            }
+        }
+    }
+}
+
 exit = {
     'state': 'exit',
 
@@ -421,7 +445,7 @@ user = {
 
 }
 
-children = '[$children={#LEM(son), #LEM(daughter)}]'
+children = '[#EXTR(children,son,sons,daughter,daughters)]'
 expecting = '[{i, we} {expecting, [{baby, one, two} on the way]}] #SET($expecting_children=True)'
 infant = '[{i, we} have, $baby=#LEM(baby)]'
 toddler = '[{i, we} have, $toddler=#LEM(toddler)]'
@@ -440,7 +464,7 @@ rules = {
     ages: '',
 }
 
-transitions = [system,want_kids,parent_question,proud,close_to,traditions]
+transitions = [system,want_kids,parent_question,proud,close_to,traditions,returning]
 for trans in transitions:
     baby.load_transitions(trans)
 
