@@ -2,10 +2,11 @@
 from _globals import PATHDIR
 from emora_stdm import DialogueFlow
 from copy import deepcopy
+from emora._flows._central_knowledge import central_knowledge
 
-backstory = DialogueFlow('_local_start')
+
+backstory = DialogueFlow('_local_start', kb=central_knowledge)
 backstory.add_system_transition('exit', 'SYSTEM:root', '#GCOM(backstory)')
-backstory.knowledge_base().load_json_file(PATHDIR.replace('__***__', '_common.json'))
 backstory.add_system_transition('_local_start', 'start', '')
 
 system = {
