@@ -1,9 +1,8 @@
 from _globals import PATHDIR
 from emora_stdm import DialogueFlow
+from emora._flows._central_knowledge import central_knowledge
 
-
-house = DialogueFlow('_local_start')
-house.knowledge_base().load_json_file(PATHDIR.replace('__***__','_common.json'))
+house = DialogueFlow('_local_start', kb=central_knowledge)
 house.add_system_transition('_local_start', 'start', '')
 
 
