@@ -1,10 +1,11 @@
 
 from _globals import PATHDIR
 from emora_stdm import DialogueFlow
+from emora._flows._central_knowledge import central_knowledge
 
 
-relationships = DialogueFlow('_local_start')
-relationships.knowledge_base().load_json_file(PATHDIR.replace('__***__', '_common.json'))
+
+relationships = DialogueFlow('_local_start', kb=central_knowledge)
 relationships.add_system_transition('_local_start', 'start', '')
 
 system = {
@@ -30,7 +31,7 @@ system = {
     '#GSRET(default_relationship)':{
         'state': 'ask_relationship',
 
-        '{#AGREE,[{[!-not,{correct,true,right}],[!i am,-not]}]}':
+        '{#AGREE,[{[!-not,{correct,true,right}],[!i am,-not,{dating,seeing {someone,somebody}}?]}]}':
             'dating_y',
 
         '[{#DISAGREE,[i am not],[not dating],noone,no one,nobody,[!not,{have,got},{a,any},#ONT(partner)]}]':
@@ -278,7 +279,7 @@ marriage = {
     '#GSRET(default_marriage)': {
         'state': 'asked_married',
 
-        '{#AGREE,[[!-not,{correct,true}]],[[!i am,-not]]}'
+        '{#AGREE,[[!-not,{correct,true}]],[!i am,-not,married?]}'
         '#SET($relationship_status=married)': {
             'state': 'married_y',
 
@@ -388,7 +389,10 @@ marriage = {
 
             '`That\'s alright. It is hard to find the right person. Are you currently seeing anyone?`'
             '#GSRET(default_relationship) #IF($entered_dating!=True) #SET($entered_dating=True)':
-                'ask_relationship'
+                'ask_relationship',
+
+            '`That\'s alright. It is hard to find the right person. `':
+                'exit'
         },
 
         'error': {
@@ -551,6 +555,31 @@ wedding_planning = {
     }
 }
 
+returning = {
+    'state': 'returning',
+    'enter': '#GATE #KNOWN($partner!=None)',
+
+    '`How\'s your ` $partner ` been?`': {
+
+        '[#ONT(_positive adj)]': {
+
+            '`I\'m not surprised. Last time, the way you talked about your partner was '
+            'really sweet, you seem like you\'re great together.`': {
+
+                '#UNX': 'exit'
+            }
+        },
+
+        'error': {
+
+            '`Last time, the way you talked about your partner was '
+            'really sweet, you seem like you\'re great together.`': {
+
+                '#UNX': 'exit'
+            }
+        }
+    }
+}
 
 exit = {
     'state': 'exit',
@@ -813,6 +842,7 @@ relationships.load_transitions(marriage)
 relationships.load_transitions(friend_married)
 relationships.load_transitions(wedding_talk)
 relationships.load_transitions(wedding_planning)
+relationships.load_transitions(returning)
 relationships.load_transitions(exit)
 relationships.load_global_nlu(user, 10.0)
 
