@@ -1,10 +1,10 @@
 
 from _globals import PATHDIR
 from emora_stdm import DialogueFlow
+from emora._flows._central_knowledge import central_knowledge
 
 
-school = DialogueFlow('_local_start')
-school.knowledge_base().load_json_file(PATHDIR.replace('__***__','_common.json'))
+school = DialogueFlow('_local_start', kb=central_knowledge)
 school.add_system_transition('_local_start', 'start', '')
 
 system = {
@@ -236,7 +236,7 @@ system = {
         },
 
         '[#NOT(not),{graduated,graduating}]'
-        '#SET($is_student=False,$is_child=False)':{
+        '#SET($is_student=False,$is_child=False,$graduated=True)':{
             'state': 'graduating',
             'score': 1.1,
 
@@ -259,6 +259,33 @@ system = {
     }
 }
 
+returning = {
+    'state': 'returning',
+    'enter': '#GATE #KNOWN($is_student=True)',
+
+    '`I guess you\'re not in school right now, right? Are you enjoying summer break?`': {
+
+        'error': {
+
+            '`That\'s great! What have you been doing with all your free time?` '
+            '#GSRET(exit)': 'hobby:activity'
+        },
+
+        '#DISAGREE': {
+
+            '`Oh really? I thought you\'d be enjoying summer vacation right now.`': {
+
+                'error': {
+
+                    '`I see. Well, how would you spend your time right now, if you '
+                    'could do anything you wanted?` '
+                    '#GSRET(exit)': 'hobby:activity'
+                }
+            }
+        }
+    }
+}
+
 exit = {
     'state': 'exit',
 
@@ -584,6 +611,7 @@ user = {
 
 school.load_transitions(system)
 school.load_transitions(exit)
+school.load_transitions(returning)
 school.load_global_nlu(user, 10.0)
 
 
