@@ -1,6 +1,8 @@
 from emora_stdm import DialogueFlow, Macro, KnowledgeBase
 import random
 from _globals import PATHDIR
+from emora._flows._central_knowledge import central_knowledge
+
 
 
 travel_database = {
@@ -14,7 +16,7 @@ travel_database = {
             "tex-mex cuisine": "from texas and mexican is an american regional cuisine that derives from the culinary creations of the tejano people of texas.",
             "cajun food": "is a style of cooking named for the french-speaking acadian people deported by the british from acadia in canada to what is now called the acadiana region of louisiana."
         },
-        "brief_intro": "houston is the most diverse metropolitan area in texas.",
+        "brief_intro": " texas.",
         "movie": {
             "urban cowboy": "was filmed in pasadena creatively chronicles the volatile relationship between the main characters bud and sissy a cowboy and cowgirl, respectively. arguably, it's one of the most famous iconic texas films out there."
         },
@@ -28,7 +30,7 @@ travel_database = {
             "macanese style portuguese chicken": "is an example of a chinese dish that draws from macanese influences, but is not part of macanese cuisine",
             "pork chop bun": "was adapted to use local ingredients, such as fresh seafood, turmeric, coconut milk, and adzuki beans. these adaptations produced macanese variations of traditional portuguese dishes including caldo verde, minchee, and cozido portuguesa."
         },
-        "brief_intro": "macau is a city on the western side of the pearl river estuary in southern china. ",
+        "brief_intro": " southern china. ",
         "movie": {
             "the man with the golden gun": "was the first to put macau on hollywoods radar. starring roger moore in the lead role of james bond, macau was selected as a shooting location because of its prevalence of casinos."
         },
@@ -44,7 +46,7 @@ travel_database = {
             "creole cuisine": "is po boy and italian muffuletta sandwiches; gulf oysters on the half-shell, boiled crawfish, and other seafood as well as creole dishes.",
             "beignets": "are square-shaped fried pastries that could be called french doughnuts, served with coffee and chicory, known as cafe au lait."
         },
-        "brief_intro": "it is a Louisiana city on the Mississippi River, famous for its Mardi Gras celebration",
+        "brief_intro": " Louisiana. ",
         "movie": {
             "interview with the vampire": ", a dramatic horror film, tells an epic vampire story where love, betrayal, loneliness, and hunger take louis de pointe du lac, a young indigo plantation owner, played by protagonist brad pitt, on a haunting adventure through the south of new orleans. "
         },
@@ -61,7 +63,7 @@ travel_database = {
             "fish and chips": "theres nothing that says british food like fish & chips. known the world over, this traditional british dish is on the top of any foodie list for visitors to london and the u.k.",
             "full english breakfast": "traditionally, you need to find a dish that incorporates: sausages, eggs, mushrooms, tomatoes, mushrooms, blood pudding, potatoes, and toast."
         },
-        "brief_intro": "london is the capital and largest city of england.",
+        "brief_intro": " england. ",
         "movie": {
             "performance 1970": "is the ultimate london movie, a tale of rock stars and thieves, creativity and confusion, drug-fuelled fantasy and hard, ugly reality."
         },
@@ -75,7 +77,7 @@ travel_database = {
         "famous_food": {
             "sourdough bread with white clam chowder": ""
         },
-        "brief_intro": "it is the cultural, commercial, and financial center of northern california.",
+        "brief_intro": " california. ",
         "movie": {
             "48 hours": "is a 1982 american buddy cop action comedy film directed by walter hill. it is joel silver's first film as a film producer."
         },
@@ -88,7 +90,7 @@ travel_database = {
         "famous_food": {
             "Seattle Dog, a cream cheese hot dog": ""
         },
-        "brief_intro": "it is the largest city in both the state of washington and the pacific northwest region of north america.",
+        "brief_intro": "washington. ",
         "movie": {
             "sleepless in seattle": "is a 1993 american romantic comedy about a recently widowed man's son calls a radio talk-show in an attempt to find his father a partner."
         },
@@ -105,7 +107,7 @@ travel_database = {
             "italian beef sandwich": "is a distinctly chicago sandwich that is thinly sliced beef simmered in au jus and served on an italian roll with sweet peppers or spicy giardiniera.",
             "chicago style hot dog": "is typically an all beef hot dog and loaded with an array of toppings."
         },
-        "brief_intro": "It is situated on Lake Michigan in Illinois and is one of the largest cities in the United States.",
+        "brief_intro": " Illinois. ",
         "movie": {
             "divergent": ", set in a futuristic chicago, is a 2014 american dystopian science fiction action film directed by neil burger, based on the 2011 novel of the same name by veronica roth."
         },
@@ -124,7 +126,7 @@ travel_database = {
             "macaron": "",
             "french oysters": " are renowned for their quality, and there are many different varieties from different parts of the french coastline."
         },
-        "brief_intro": "paris is the capital and most populous city of france.",
+        "brief_intro": " france. ",
         "movie": {
             "mission impossible fallout": "is the sixth instalment of the mission impossible spy film series, written, produced and directed by christopher mcquarrie. it offers a thrilling taste of the french capital."
         },
@@ -144,7 +146,7 @@ travel_database = {
             "New York-style pizza":"",
             "Manhattan Clam Chowder": ""
         },
-        "brief_intro": "new york city has been described as the cultural, financial, and media capital of the world.",
+        "brief_intro": " new york. ",
         "movie": {
             "do the right thing": "even 23 years its release,remains the most immediate and alive exploration of life in the simmering melting pot."
         },
@@ -164,7 +166,7 @@ travel_database = {
             "grilled pork": "is a sweet, succulent and tender piece of meat on a stick. this particular stall, moo ping hea owen is recommended by many locals",
             "sweet potato balls": "is lightly crisp on the outside and airily soft on the inside. "
         },
-        "brief_intro": "bangkok is the capital and most populous city of thailand.",
+        "brief_intro": " thailand. ",
         "movie": {
             "tomorrow never dies": "features one of the best chase scenes which was filmed in bangkok."
         },
@@ -183,7 +185,7 @@ travel_database = {
             "lomi-lomi": "is a must try for those who love fish. traditionally served as a side salad dish at laus feasts, it consists of chopped raw salmon and diced tomatoes and onions massaged together by hand.",
             "kalua pig": "is the centrepiece of hawaiian feasts and once reserved for only the chiefs and king of hawaiian society at laus feasts."
         },
-        "brief_intro": "it is the largest city and state capital city of hawaii.",
+        "brief_intro": " hawaii. ",
         "movie": {
             "50 first dates": "is a funny and engaging comedy that naturally brings out the charming connection that these two actors share as a perfect casting pairing. ",
             "soul surfer": "is the inspirational story that every surf girl waited for on the big screen; glimpses of the early years of famous female hawaii surfer, bethany hamilton."
@@ -203,7 +205,7 @@ travel_database = {
         "famous_food": {
             "luqaimat": "they are hot dumplings with a similar taste and texture to doughnuts."
         },
-        "brief_intro": "dubai is the most populous city in the united arab emirates and the capital of the emirate of dubai.",
+        "brief_intro": " the middle east. ",
         "movie": {
             "syriana": "weaves together several stories set in the world of petroleum politics. the desert scenes are based in iran but many of them were actually shot in the dubai desert."
         },
@@ -221,7 +223,7 @@ travel_database = {
             "florida orange juice": "is a good to start your day, with a refreshing, vitamin c-packed glass of oj. sure, you can probably find a fancy juice bar that will charge you $5 a glass, but it cant get any fresher than if you squeeze it at home.",
             "the cuban sandwich": " is one of the best sandwiches ever invented. these days, you can find it across the state, but the very best ones are made in florida."
         },
-        "brief_intro": " it is a city in Florida, home to many exciting theme parks.",
+        "brief_intro": " Florida. ",
         "movie": {
             "2 fast 2 furious": ", one of the defining movies of the 2000s, was the anticipated follow-up to street racing classic the fast and the furious."
         },
@@ -240,7 +242,7 @@ travel_database = {
         "famous_food": {
             "french dip sandwich": ""
         },
-        "brief_intro": "los angeles is the cultural, financial, and commercial center of southern california.",
+        "brief_intro": " southern california. ",
         "movie": {
             "la la land": "is a completely original musical vibrating with the spirit of frances immortal the umbrellas of cherbourg yet alive with the dreams of todays angelenos, writer director damien chazelles swirling masterpiece gave us a career-best performance from emma stone, heartbreaking in every shot."
         },
@@ -257,52 +259,29 @@ travel_database = {
 class RANDOM(Macro):
 
     def run(self, ngrams, vars, args):
-        city_info = travel_database[vars["city"]]
+        city_info = travel_database[vars["talked_about_city"]]
         options = list(city_info[args[0]].keys())
         return random.choice(options)
 
 class CITY_DETAIL(Macro):
 
     def run(self, ngrams, vars, args):
-        city_info = travel_database[vars["city"]]
+        city_info = travel_database[vars["talked_about_city"]]
         return city_info[args[0]]
 
 class TOURISM_DETAIL(Macro):
 
     def run(self, ngrams, vars, args):
-        city_info = travel_database[vars["city"]]
+        city_info = travel_database[vars["talked_about_city"]]
         return city_info["tourist_attraction"][vars["attraction"]]
 
-travel_ont = {
-    "ontology": {
-        "known_cities": [
-            "macau","paris","houston","chicago","london","san francisco","new orleans","seattle",
-            "orlando","los angeles","bangkok","dubai","honolulu","new york city"
-        ],
-
-        "other_cities": [
-            "tokyo","jakarta","chongqing","manila","delhi","seoul","mumbai","shanghai","sao paulo","beijing",
-            "lagos","mexico city","guangzhou","dhaka","osaka","cairo","karachi","moscow","chengdu",
-            "kolkata","buenos aires","tehran","tianjin","kinshasa","rio de janeiro",
-            "baoding", "lahore", "lima", "bangalore", "ho chi minh", "harbin", "wuhan", "shijiazhuang", "bogota", "suzhou",
-            "linyi", "chennai", "nagoya", "nanyang", "zhengzhou", "hyderabad", "surabaya", "hangzhou", "johannesburg",
-            "quanzhou", "taipei", "dongguan", "bandung", "hanoi", "shenyang", "baghdad", "onitsha",
-            "ahmedabad", "luanda", "dallas", "pune", "nanjing", "boston", "santiago",
-            "riyadh", "dusseldorf", "madrid", "toronto", "surat"
-        ]
-    }
-}
-
 macros = {
     'RANDOM': RANDOM(),
     'DETAIL': CITY_DETAIL(),
     'TOURISM_DETAIL': TOURISM_DETAIL(),
 }
 
-kb = KnowledgeBase()
-kb.load_json(travel_ont)
-kb.load_json_file(PATHDIR.replace('__***__', '_common.json'))
-df = DialogueFlow('start', initial_speaker=DialogueFlow.Speaker.SYSTEM, macros=macros,kb=kb)
+df = DialogueFlow('start', initial_speaker=DialogueFlow.Speaker.SYSTEM, macros=macros,kb=central_knowledge)
 
 df.add_state('start', enter='#GCOM(travel) #GOAL(travel)')
 
@@ -340,7 +319,7 @@ df.add_system_transition('TRAVEL_N', 'travel_n_followup_pet',
 df.add_system_transition('TRAVEL_Y', 'TRAVEL_TIME',
                        '"I think travelling is pretty amazing, too! To go to new places and see all of the amazing '
                          'sights is a great experience. So, are you an early-riser during '
-                         'a vacation or do you sleep in to be well-rested for the events of each day?"'
+                         'a vacation or do you like to sleep in?"'
                        '#GSRET(ask_if_plan)')
 df.add_system_transition('TRAVEL_Y', 'TRAVEL_PET',
                        '"So, you enjoy travelling? I remember you mentioned that you have a pet. '
@@ -349,7 +328,7 @@ df.add_system_transition('TRAVEL_Y', 'TRAVEL_PET',
 df.add_system_transition('travel_unx', 'TRAVEL_TIME',
                        '"Personally, I love to travel to see all of the amazing '
                          'sights. When you do travel, are you an early-riser '
-                         'or do you sleep in to be well-rested for the events of each day?"'
+                         'or do you like to sleep in?"'
                        '#GSRET(ask_if_plan)')
 
 df.add_user_transition('TRAVEL_PET', 'TRAVEL_PET_Y',
@@ -360,14 +339,12 @@ df.set_error_successor('TRAVEL_PET', 'TRAVEL_PET_N')
 
 df.add_system_transition('TRAVEL_PET_Y', 'TRAVEL_TIME',
                        '"Wow, it sounds like " $pet_name " is a lucky animal to be able to travel with you to new places! '
-                         'So, are you an early-riser during a vacation or do you sleep in to be well-rested for '
-                         'the events of each day?"'
+                         'So, are you an early-riser during a vacation or do you like to sleep in?"'
                        '#GSRET(ask_if_plan)', score=2.0)
 df.add_system_transition('TRAVEL_PET_N', 'TRAVEL_TIME',
                        '"I guess it can be better to leave them home when you travel. '
                          'I\'ve heard that a lot of pets are not used to long trips, especially in foreign locations. '
-                         'So, are you an early-riser during a vacation or do you sleep in to be well-rested for '
-                         'the events of each day?"'
+                         'So, are you an early-riser during a vacation or do you like to sleep in?"'
                        '#GSRET(ask_if_plan)')
 
 # early riser or sleep in?
@@ -381,8 +358,8 @@ df.set_error_successor('TRAVEL_TIME', 'TRAVEL_TIME_D')
 
 df.add_system_transition('TRAVEL_TIME_E', 'TRAVEL_PLAN',
                        '"I really admire people who can get up early during vacations. '
-                         'You must have a lot of discipline. Speaking of which, do you like to plan each step of your '
-                         'day or be more spontaneous? "'
+                       'I definitely struggle to not sleep in too late myself! I wonder if we are different on '
+                       'this preference too. Do you like to plan each step of your day or are you more spontaneous? "'
                        '#GSRET(ask_travel_eat)')
 df.add_system_transition('TRAVEL_TIME_L', 'TRAVEL_PLAN',
                        '"Oh yes! Sleeping in is definitely much easier than getting up early! It\'s also easier to '
@@ -391,10 +368,10 @@ df.add_system_transition('TRAVEL_TIME_L', 'TRAVEL_PLAN',
                        '#GSRET(ask_travel_eat)')
 df.add_system_transition('TRAVEL_TIME_D', 'TRAVEL_PLAN',
                        '"I get that. It can be tough to decide whether to wake up early or sleep in. '
-                         'Speaking of which, do you like to plan each step of your day or be more spontaneous about it?"'
+                         'Speaking of decisions, do you like to plan each step of your day or be more spontaneous about it?"'
                        '#GSRET(ask_travel_eat)')
 df.add_system_transition('ask_if_plan', 'TRAVEL_PLAN',
-                       '"So, do you like to plan each step of your day or be more spontaneous about it?"'
+                       '"Oh! Do you also like to plan each step of your day or are you more spontaneous about it?"'
                        '#GSRET(ask_travel_eat)')
 
 # planner or spontaneous?
@@ -406,53 +383,44 @@ df.add_user_transition('TRAVEL_PLAN', 'TRAVEL_PLAN_D',
                        '{#IDK,[{not every step, not each step, between, mostly, sometimes, both}]}')
 df.set_error_successor('TRAVEL_PLAN', 'TRAVEL_PLAN_D')
 
-df.add_system_transition('TRAVEL_PLAN_Y', 'TRAVEL_EAT',
+df.add_system_transition('TRAVEL_PLAN_Y', 'present_city',
                        '"I wish I could say that I am a good planner, but honestly I need someone like you to travel '
-                         'with me to keep us on track! I bet that you plan plenty of time to enjoy your meals on '
-                         'vacation. Or do you tend to scarf them down to get moving again? "'
-                       '#GSRET(present_city)')
-df.add_system_transition('TRAVEL_PLAN_N', 'TRAVEL_EAT',
+                         'with me to keep us on track! Actually, "')
+df.add_system_transition('TRAVEL_PLAN_N', 'present_city',
                        '"I would say that I am pretty spontaneous too. I like to keep moving to the next fun thing! '
-                         'Do you scarf down your meals in order to get moving again, or do you like to enjoy your meals '
-                         'while on vacation?"'
-                       '#GSRET(present_city)')
-df.add_system_transition('TRAVEL_PLAN_D', 'TRAVEL_EAT',
-                       '"Makes sense. A little bit of both is probably best. '
-                         'I bet that you allow for plenty of time to enjoy your meals on '
-                         'vacation. Or do you tend to scarf them down to get moving again?"'
-                       '#GSRET(present_city)')
-df.add_system_transition('ask_travel_eat', 'TRAVEL_EAT',
-                       '"So, are you the type of person who spends time enjoying your meals on '
-                         'vacation. Or do you tend to scarf them down to get moving again?"'
-                       '#GSRET(present_city)')
+                       'Actually, "')
+df.add_system_transition('TRAVEL_PLAN_D', 'present_city',
+                       '"Makes sense. A little bit of both is probably best. So, "')
+df.add_system_transition('ask_travel_eat', 'present_city',
+                       '"That\'s an interesting perspective. Anyway, "')
 
 # enjoy food or a chore
-df.add_user_transition('TRAVEL_EAT', 'TRAVEL_EAT_D',
-                       '{#IDK,[{depends, sometimes, quality, maybe, not sure, sometimes, both}]}')
-df.add_user_transition('TRAVEL_EAT', 'TRAVEL_EAT_Y',
-                       '[{first, linger, like, enjoy, local, try, former, food, foodie, stay, stop, slow, slowly}]')
-df.add_user_transition('TRAVEL_EAT', 'TRAVEL_EAT_N',
-                       '[{latter, finish, [eat,car], snack, second, moving, scar, quick, quickly, fast, scarfing, swallow, swallowing, waste of time}]')
-df.set_error_successor('TRAVEL_EAT', 'TRAVEL_EAT_D')
-
-df.add_system_transition('TRAVEL_EAT_Y', 'present_city',
-                       '"I like to take time to enjoy my meals, too. Especially since I am always trying new foods '
-                         'when I travel. "')
-df.add_system_transition('TRAVEL_EAT_N', 'present_city',
-                       '"So, I take it that enjoying the sights and culture is more important to you than '
-                         'spending a lot of time at a meal! "')
-df.add_system_transition('TRAVEL_EAT_D', 'present_city',
-                         '"I get that. It really depends on your state of mind and whatever else you have going on '
-                         'that day. "')
+# df.add_user_transition('TRAVEL_EAT', 'TRAVEL_EAT_D',
+#                        '{#IDK,[{depends, sometimes, quality, maybe, not sure, sometimes, both}]}')
+# df.add_user_transition('TRAVEL_EAT', 'TRAVEL_EAT_Y',
+#                        '[{first, linger, like, enjoy, local, try, former, food, foodie, stay, stop, slow, slowly}]')
+# df.add_user_transition('TRAVEL_EAT', 'TRAVEL_EAT_N',
+#                        '[{latter, finish, [eat,car], snack, second, moving, scar, quick, quickly, fast, scarfing, swallow, swallowing, waste of time}]')
+# df.set_error_successor('TRAVEL_EAT', 'TRAVEL_EAT_D')
+#
+# df.add_system_transition('TRAVEL_EAT_Y', 'present_city',
+#                        '"I like to take time to enjoy my meals, too. Especially since I am always trying new foods '
+#                          'when I travel. "')
+# df.add_system_transition('TRAVEL_EAT_N', 'present_city',
+#                        '"So, I take it that enjoying the sights and culture is more important to you than '
+#                          'spending a lot of time at a meal! "')
+# df.add_system_transition('TRAVEL_EAT_D', 'present_city',
+#                          '"I get that. It really depends on your state of mind and whatever else you have going on '
+#                          'that day. "')
 
 
 # emora share city of interest
 df.add_system_transition('present_city', 'ASK_TRAVEL',
-                       '"One of the most interesting cities I have heard of is " $city=#ONT(known_cities) "." #DETAIL(brief_intro) ". Have you ever been to this city before?"'
+                       '"One of the most interesting cities I have heard of is " $talked_about_city=#ONT(known_cities) " in " #DETAIL(brief_intro) ". Have you ever been to this city before?"'
                        '#GSRET(share_reason_for_travel)')
 df.update_state_settings('present_city', system_multi_hop=True)
 df.add_system_transition('share_reason_for_travel', 'CITY_DISCUSS',
-                       '"I heard that " $city " " #DETAIL(reason_for_travel)". '
+                       '"I heard that " $talked_about_city " " #DETAIL(reason_for_travel)". '
                          'Does this sound like a place you would want to visit?"'
                        '#GSRET(ask_try_food)')
 
@@ -477,7 +445,7 @@ df.add_user_transition('CITY_RECOMMEND', 'CITY_RECOMMEND_N',
 df.set_error_successor('CITY_RECOMMEND', 'CITY_RECOMMEND_N')
 
 df.add_system_transition('CITY_RECOMMEND_Y', 'USER_REC_CITY',
-                       '"Thanks for your recommendation！I will have to look into that place. What is your favorite thing about it?"'
+                       '"Thanks for your recommendation! I will have to look into that place. What is your favorite thing about it?"'
                        '#GSRET(END)')
 df.add_system_transition('CITY_RECOMMEND_N', 'END',
                        '"No big deal. I will keep looking into different places and I will let you know if I find any '
@@ -501,13 +469,13 @@ df.add_system_transition('CITY_NOT_TRAVELED', 'CITY_DISCUSS',
                        '#GSRET(ask_try_food)')
 
 df.add_system_transition('city_travelled_unx', 'CITY_DISCUSS',
-                       '"I heard that " $city " " #DETAIL(reason_for_travel)". '
+                       '"I heard that " $talked_about_city " " #DETAIL(reason_for_travel)". '
                          'Does this sound like an interesting place?"'
                        '#GSRET(ask_try_food)')
 
 df.add_system_transition('ask_try_food', 'FOOD_RECOMMEND',
                        '"Well, I am really excited to try the " '
-                         '$food=#RANDOM(famous_food)" in " $city ". Would you try that food too?"'
+                         '$food=#RANDOM(famous_food)" in " $talked_about_city ". Would you try that food too?"'
                        '#GSRET(present_attraction)')
 
 df.add_user_transition('CITY_DISCUSS', 'NOT_THE_CITY',
@@ -537,14 +505,14 @@ df.add_system_transition('FOOD_RECOMMEND_N', 'present_attraction',
                        '"Really? I didn\'t think it sounded too bad! "')
 
 df.add_system_transition('present_attraction', 'ATTRACTION_RECOMMEND',
-                       '"One place in " $city " that really caught my attention is " '
+                       '"One place in " $talked_about_city " that really caught my attention is " '
                          '$attraction=#RANDOM(tourist_attraction) ". '
                          'It " #TOURISM_DETAIL ". '
                          'Does this sound like an interesting place for you too?"'
                        '#GSRET(present_movie)')
 
 df.add_system_transition('present_movie', 'MOVIE_REC',
-                       '"You know, since I can\'t actually travel to " $city ", '
+                       '"You know, since I can\'t actually travel to " $talked_about_city ", '
                          'I was thinking of watching the movie " $movie=#RANDOM(movie) " because it takes '
                          'place there. Have you seen it?"'
                        '#GSRET(ask_user_fave_city)')
@@ -560,12 +528,12 @@ df.set_error_successor('ATTRACTION_RECOMMEND', 'ATTRACTION_RECOMMEND_Y')
 df.add_system_transition('ATTRACTION_RECOMMEND_N', 'MOVIE_REC',
                        '"I guess everyone has different tastes. You know, since I can\'t actually travel there, '
                          'I was thinking of watching the movie " $movie=#RANDOM(movie) " because it takes '
-                         'place in " $city ". Have you seen it?"'
+                         'place in " $talked_about_city ". Have you seen it?"'
                        '#GSRET(ask_user_fave_city)')
 df.add_system_transition('ATTRACTION_RECOMMEND_Y', 'MOVIE_REC',
                        '"Wow, we seem to agree on a lot of things! You know, since I can\'t actually travel there, '
                          'I was thinking of watching the movie " $movie=#RANDOM(movie) " because it takes '
-                         'place in " $city ". Have you seen it?"'
+                         'place in " $talked_about_city ". Have you seen it?"'
                        '#GSRET(ask_user_fave_city)')
 
 # user been to presented city
@@ -588,12 +556,12 @@ df.add_system_transition('REASON_N', 'CITY_RECOMMEND',
                        '#GSRET(END)')
 df.add_system_transition('REASON_Y', 'ATTRACTION_OPINION',
                        '"Cool! I thought that was a really compelling reason to go, so I am glad it\'s true. '
-                         'One place in " $city " that really caught my attention is " '
+                         'One place in " $talked_about_city " that really caught my attention is " '
                          '$attraction=#RANDOM(tourist_attraction) ". '
                          'Would you recommend visiting it on a trip?"'
                        '#GSRET(present_movie)')
 df.add_system_transition('REASON_NOT_SURE', 'ATTRACTION_OPINION',
-                       '"Okay. Well, one place in " $city " that really caught my attention is " '
+                       '"Okay. Well, one place in " $talked_about_city " that really caught my attention is " '
                          '$attraction=#RANDOM(tourist_attraction) ". '
                          'Would you recommend visiting it on a trip?"'
                        '#GSRET(present_movie)')
@@ -609,17 +577,17 @@ df.set_error_successor('ATTRACTION_OPINION', 'ATTRACTION_OPINION_D')
 df.add_system_transition('ATTRACTION_OPINION_Y', 'MOVIE_REC',
                        '"Nice! I would love to see it in person then. You know, since I can\'t actually travel there, '
                          'I was thinking of watching the movie " $movie=#RANDOM(movie) " because it takes '
-                         'place in " $city ". Have you seen it?"'
+                         'place in " $talked_about_city ". Have you seen it?"'
                        '#GSRET(ask_user_fave_city)')
 df.add_system_transition('ATTRACTION_OPINION_N', 'MOVIE_REC',
                        '"Ah ok. I was hoping it was cool, but maybe not. You know, since I can\'t actually travel there, '
                          'I was thinking of watching the movie " $movie=#RANDOM(movie) " because it takes '
-                         'place in " $city ". Have you seen it?"'
+                         'place in " $talked_about_city ". Have you seen it?"'
                        '#GSRET(ask_user_fave_city)')
 df.add_system_transition('ATTRACTION_OPINION_D', 'MOVIE_REC',
                        '"Okay, thats fine. You know, since I can\'t actually travel there, '
                          'I was thinking of watching the movie " $movie=#RANDOM(movie) " because it takes '
-                         'place in " $city ". Have you seen it?"'
+                         'place in " $talked_about_city ". Have you seen it?"'
                        '#GSRET(ask_user_fave_city)')
 
 df.add_system_transition('ask_user_fave_city', 'ASK_FAV_CITY',
@@ -628,7 +596,7 @@ df.add_system_transition('ask_user_fave_city', 'ASK_FAV_CITY',
                        '#GSRET(END)')
 
 
-# Movie that takes place in $city
+# Movie that takes place in $talked_about_city
 df.add_user_transition('MOVIE_REC', 'MOVIE_REC_N',
                        '{#DISAGREE, [{what is it, what was it, never heard,[not, {watch, watched, seen, saw}]}]}')
 df.add_user_transition('MOVIE_REC', 'MOVIE_REC_Y',
@@ -640,7 +608,7 @@ df.add_system_transition('MOVIE_REC_N', 'ASK_FAV_CITY',
                          'You know what? We have been talking about one of my favorite cities a lot, '
                          'so now I\'m curious what yours is?"'
                        '#GSRET(END)')
-df.add_system_transition('MOVIE_REC_HAVE_WATCHED', 'ASK_FAV_CITY',
+df.add_system_transition('MOVIE_REC_Y', 'ASK_FAV_CITY',
                        '"Oh, you have? I will have to check it out too then! '
                          'You know what? We have been talking about one of my favorite cities a lot, '
                          'so now I\'m curious what yours is?"'
@@ -649,7 +617,7 @@ df.add_system_transition('MOVIE_REC_HAVE_WATCHED', 'ASK_FAV_CITY',
 # user's favorite location
 df.add_user_transition('ASK_FAV_CITY', 'FAV_SAME',
                        '[$user_fav_city=#ONT(known_cities)]')
-df.add_user_transition('ASK_FAV_CITY', 'NO_MATCH',
+df.add_user_transition('ASK_FAV_CITY', 'RECOG_CITY',
                        '[$user_fav_city=#ONT(other_cities,_location)]')
 df.add_user_transition('ASK_FAV_CITY', 'FAV_NO',
                        '{#DISAGREE,#IDK,[not have]}')
@@ -657,8 +625,10 @@ df.set_error_successor('ASK_FAV_CITY', 'NO_MATCH')
 
 df.add_system_transition('FAV_SAME', 'END',
                        '"Oh yeah! " $user_fav_city " is also on the top of my list, maybe we should talk about it in the future! "')
+df.add_system_transition('RECOG_CITY', 'END',
+                       '"Oh cool! I do not know much about " $user_fav_city ", maybe we should talk about it in the future! "')
 df.add_system_transition('NO_MATCH', 'END',
-                       '"Oh cool! I do not know much about " $user_fav_city ", maybe we should talk about it in the future!"')
+                       '"That sounds interesting, maybe we should talk about it in the future! "')
 df.add_system_transition('FAV_NO', 'END',
                        '"Not everyone has one, I guess. You will have to let me know if you ever hear of a place '
                          'that you would love to travel to! "')
@@ -670,7 +640,7 @@ exit = {
 
     '#GCOM(travel) #GRET': {
         'score': 0.0,
-        'state':'SYSTEM:root'
+        'state':'SYSTEM:travel_topic_switch'
     }
 }
 
