@@ -1,10 +1,10 @@
 
 from _globals import PATHDIR
 from emora_stdm import DialogueFlow
+from emora._flows._central_knowledge import central_knowledge
 
 
-work = DialogueFlow('_local_start')
-work.knowledge_base().load_json_file(PATHDIR.replace('__***__', '_common.json'))
+work = DialogueFlow('_local_start', kb=central_knowledge)
 work.add_system_transition('_local_start', 'start', '')
 
 system = {
@@ -164,6 +164,24 @@ system = {
     }
 }
 
+returning = {
+    'state': 'returning',
+    'enter': '#GATE #KNOWN($is_employed=True)',
+
+    '`How have things been at work?`': {
+
+        '[#ONT(_positive adj)]': {
+
+            '`That\'s good.`': 'exit'
+        },
+
+        'error': {
+
+            '`Well let\'s talk about something more interesting then.`': 'exit'
+        }
+    }
+}
+
 job_wishes = {
     'state': 'job_wishes',
 
@@ -444,7 +462,7 @@ user = {
     }
 }
 
-transitions = [system,emoras_job_wish,job_wishes]
+transitions = [system,emoras_job_wish,job_wishes,returning]
 for trans in transitions:
     work.load_transitions(trans)
 
